@@ -1,11 +1,7 @@
-/***************************************************************************
- *                                                                         *
- *   SPDX-FileCopyrightText: 2020 Jonah Brüchert <jbb@kaidan.im>           *
- *   SPDX-FileCopyrightText: 2020 Rinigus <rinigus.git@gmail.com>          *
- *                                                                         *
- *   SPDX-License-Identifier: GPL-2.0-or-later                             *
- *                                                                         *
- ***************************************************************************/
+// SPDX-FileCopyrightText: 2020 Jonah Brüchert <jbb@kaidan.im>
+// SPDX-FileCopyrightText: 2020 Rinigus <rinigus.git@gmail.com>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
 #ifndef USERAGENT_H
 #define USERAGENT_H
@@ -29,7 +25,7 @@ public:
     bool isMobile() const;
     void setIsMobile(bool value);
 
-signals:
+Q_SIGNALS:
     void isMobileChanged();
     void userAgentChanged();
 
